/**
 * @overview WMF Utility Class
 * @author Jan "Waffle" Christophersen
 * @copyright (c) Jan "Waffle" Christophersen
 */

'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

var _customLogger = require('custom-logger');

var _customLogger2 = _interopRequireDefault(_customLogger);

var _colors = require('colors');

var _colors2 = _interopRequireDefault(_colors);

//eslint-disable-line

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

/** @type customLogger */
var logger = _customLogger2['default']['new']({
  todo: { level: 1, event: 'todo', color: 'cyan' },
  db: { level: 1, event: 'db'.bgCyan }
}).config({
  level: 0,
  timestamp: 'dd.mm.yyyy, HH:MM:ss'
});

/**
 * The Utilitly class provides various functions and utilities.
 */

var WMFUtility = (function () {
  function WMFUtility() {
    _classCallCheck(this, WMFUtility);
  }

  _createClass(WMFUtility, null, [{
    key: 'readdir',

    /**
     * Reads a Directory and returns all file names.
     *
     * @param {string} directory - path to the directory
     * @param {boolean} [recursive=true] - go through subdirectories
     * @returns {Promise.<Set.<string>>}
     */
    value: function readdir(directory) {
      var _this = this;

      var recursive = arguments.length <= 1 || arguments[1] === undefined ? true : arguments[1];

      return new Promise(function (resolve, reject) {
        log.debug('WMFUtility#readdir ' + directory);
        var files = new Set();
        var dir = _path2['default'].normalize(directory);
        _fs2['default'].readdir(dir, function (err, dirFiles) {
          if (err) {
            return reject(err);
          }

          var subdirs = [];
          for (var idx = 0; idx < dirFiles.length; idx++) {
            files.add(dirFiles[idx]);

            if (recursive) {
              var stat = _fs2['default'].statSync(_path2['default'].join(directory, dirFiles[idx]));

              if (stat.isDirectory()) {
                subdirs.push(dirFiles[idx]);
              }
            }
          }

          if (!recursive) {
            return resolve(files);
          }

          var promises = [];
          subdirs.forEach(function (sd) {
            promises.push(_this.readdir(_path2['default'].join(directory, sd), recursive).then(function (subfiles) {
              var fset = new Set();
              subfiles.forEach(function (file) {
                fset.add(_path2['default'].join(sd, file));
              });
              return fset;
            }));
          });

          Promise.all(promises).then(function (subFiles) {
            subFiles.forEach(function (set) {
              set.forEach(function (subFile) {
                files.add(subFile);
              });
            });
            return resolve(files);
          })['catch'](reject);
        });
      });
    }
  }, {
    key: 'fs',

    /**
     * Returns the fs object
     *
     * @type {fs}
     */
    get: function get() {
      return _fs2['default'];
    }

    /**
     * Returns the Log object
     *
     * @type {Log}
     */
  }, {
    key: 'log',
    get: function get() {
      return logger;
    }

    /**
     * Returns the path object
     *
     * @type {path}
     */
  }, {
    key: 'path',
    get: function get() {
      return _path2['default'];
    }
  }]);

  return WMFUtility;
})();

exports['default'] = WMFUtility;
module.exports = exports['default'];
//# sourceMappingURL=wmfUtility.js.map